package VMOMI::DrsBehavior;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
